==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/base/BasBankAccount.md <==
select
===
select @pageTag(){
				t.BANK_ACCOUNT_ID,
		t.ORG_ID,
		t.BANK_ID,
		t.ACCOUNT_CLASS_ID,
		t.ACCOUNT_NAME,
		t.ACCOUNT_NO,
		t.ACCOUNT_USE,
		GETDICNAME('ACCOUNT_USE',t.ACCOUNT_USE) ACCOUNT_USE_TEXT,
		t.ACCOUNT_DATE,
		t.REMARK,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE,
		GETDICNAME('IS_USE',t.IS_USE) IS_USE_TEXT,
		t.ACCOUNT_TYPE,
		GETDICNAME('ACCOUNT_TYPE',t.ACCOUNT_TYPE) ACCOUNT_TYPE_TEXT,
		nvl(a.abbr,a.org_name) as abbr,
		b.ACCOUNT_NAME as MODIFY_ACCOUNT_NAME,
		c.BANK_NAME,
		t.init_Money,
		(NVL(t.init_Money,0)+(select sum(nvl(a.debit_amount, 0)) - sum(nvl(a.lender_amount, 0))BALANCE
  from FM_BANK_JOURNAL a
 where a.is_use = 'Y'
   and a.bank_no = t.BANK_ACCOUNT_ID)) BALANCE
	 @}
from BAS_BANK_ACCOUNT t
left join bas_org a on t.org_id=a.org_id 
left join bas_emp_account b on t.MODIFY_ACCOUNT=b.account_id 
left join BAS_BANK c on t.bank_id=c.bank_id 
where t.BANK_ID in (WITH recursive temp AS (
	SELECT
		t.BANK_ID id 
	FROM
		BAS_BANK T 
	WHERE
		T.BANK_PID = #bankid# 
		OR T.BANK_ID = #bankid# UNION ALL
	SELECT
		t.BANK_ID id 
	FROM
		BAS_BANK T,
		temp 
	WHERE
		temp.id = T.BANK_PID 
	) SELECT
	DISTINCT * 
FROM
	temp) and t.is_use='Y'
@if(!isEmpty(orgid)){
and  a.org_id = #orgid#
@}
@if(!isEmpty(isEnAnble)){
 and nvl(t.IS_ENANBLE,'N') = #isEnAnble#
@}
@if(!isEmpty(search)){
and(
 upper(t.BANK_ACCOUNT_ID) like #search#  or 
 upper(t.ORG_ID) like #search#  or 
 upper(t.BANK_ID) like #search#  or 
 upper(t.ACCOUNT_CLASS_ID) like #search#  or 
 upper(t.ACCOUNT_NAME) like #search#  or 
 upper(t.ACCOUNT_NO) like #search#  or 
 upper(t.ACCOUNT_USE) like #search#  or 
 upper(t.ACCOUNT_DATE) like #search#  or 
 upper(t.REMARK) like #search#  or 
 upper(t.MODIFY_ACCOUNT) like #search#  or 
 upper(t.MODIFY_TIME) like #search#  or 
 upper(t.IS_USE) like #search#  or 
 upper(t.ACCOUNT_TYPE) like #search# or
 upper(a.org_name) like #search#
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.org_id,t.ACCOUNT_DATE desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectBankAccountTree
===

WITH recursive temp AS (
	SELECT concat('b',	t.BANK_ID) id, t.BANK_ID,
		 concat('b', T.BANK_PID) PID, T.BANK_PID,
     	t.BANK_NAME text,
     	t.BANK_TYPE,
     	null as value
 FROM 	BAS_BANK T 
 WHERE 	t.IS_USE = 'Y'
 AND T.BANK_PID = 0 UNION ALL
	SELECT concat('b',	t.BANK_ID) id, t.BANK_ID,
		 concat('b', T.BANK_PID) PID, T.BANK_PID,
     	t.BANK_NAME text,
     	t.BANK_TYPE,
     	null as value
 FROM 	BAS_BANK T,temp WHERE temp.BANK_ID = T.BANK_PID
	) SELECT
	id,PID,text,BANK_TYPE,value
FROM
	temp 
 union all
SELECT concat('',t.bank_account_id) id, 
		concat('b',  T.BANK_ID) PID, 
     	concat(t.account_no,' ',t.account_name) text,
     	NULL AS BANK_TYPE,
        t.account_no as value
 FROM 	Bas_Bank_Account T 
 WHERE 	t.IS_USE = 'Y'

 
findDataByAccountData
===
SELECT T.*, T.ROWID
  FROM BAS_BANK_ACCOUNT T
 WHERE T.IS_USE = 'Y'
   and t.org_id =#orgId#
   and t.account_name =#bankName#
   and t.account_no =#bankAccount#
   
PageBasBankDeposit
===
select @pageTag(){
		t.BANK_ACCOUNT_ID,
		t.ORG_ID,
		t.BANK_ID,
		t.ACCOUNT_CLASS_ID,
		t.ACCOUNT_NAME,
		t.ACCOUNT_NO,
		t.ACCOUNT_USE,
		c.bank_name,
		t.ACCOUNT_DATE,
		nvl(e.THE_PERIOD_MONEY,0) THE_PERIOD_MONEY,
		nvl((SELECT nvl(i.init_money,0) FROM Fm_Balance_Init i 
                           WHERE i.IS_USE = 'Y' 
                           and i.balance_type = 2
                           and i.bank_account_id =t.bank_account_id ),0)+nvl((select sum(nvl(a1.debit_amount, 0))  -  sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time<=TRUNCATE(NOW(), 'MONTH')), 0) init_money,
nvl((select sum(nvl(a1.debit_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time>=TRUNCATE(NOW(), 'month') 
                                                                                  and a1.create_time<= NOW()), 0) month_sr,
nvl((select sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time>=TRUNCATE(NOW(), 'month')
                                                                                    and a1.create_time<= NOW()), 0) month_zc,
nvl((SELECT nvl(i.init_money,0) FROM Fm_Balance_Init i 
                           WHERE i.IS_USE = 'Y' 
                           and i.balance_type = 2
                           and i.bank_account_id =t.bank_account_id ),0)+nvl((select sum(nvl(a1.debit_amount, 0))  -  sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time<NOW()), 0) over_money,
		t.REMARK
	 @}
from BAS_BANK_ACCOUNT t
left join bas_org b on t.org_id=b.org_id 
left join BAS_BANK c on t.bank_id=c.bank_id 
left join (SELECT bj.*,(row_number() over(partition by bj.bank_no order by bj.BUSINESS_DATE,bj.BANK_JOURNAL_ID desc)) rn from FM_BANK_JOURNAL bj 
where bj.business_date<TRUNCATE(NOW(), 'mm') and bj.is_use='Y') d  on d.rn=1 and t.BANK_ACCOUNT_ID=d.bank_no 
left join (select * from (select NVL(a.the_period_money, 0) the_period_money,
                                      a.the_period_date,
                                      A.BANK_ACCOUNT_ID,
                                      row_number() over(partition by A.BANK_ACCOUNT_ID order by A.the_period_date desc, a.account_check_id desc) rn
                                 from FM_BANK_ACCOUNT_CHECK A
                                where A.IS_USE = 'Y'
                                  and a.check_status = 'Y') f
                        where rn = 1) e
              on t.bank_account_id = e.BANK_ACCOUNT_ID
where t.is_use='Y'
@if(!isEmpty(orgid)){
and  t.org_id = #orgid#
@}
@if(!isEmpty(search)){
and(
 upper(t.BANK_ACCOUNT_ID) like #search#  or 
 upper(t.ORG_ID) like #search#  or 
 upper(t.BANK_ID) like #search#  or 
 upper(t.ACCOUNT_CLASS_ID) like #search#  or 
 upper(t.ACCOUNT_NAME) like #search#  or 
 upper(t.ACCOUNT_NO) like #search#  or 
 upper(b.org_name) like #search#
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.org_id,t.ACCOUNT_DATE desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

==> fine-web-0.0.2-20220913.113206-173.jar: beetlsql/base/BasBankAccount.md <==
select
===
select @pageTag(){
				t.BANK_ACCOUNT_ID,
		t.ORG_ID,
		t.BANK_ID,
		t.ACCOUNT_CLASS_ID,
		t.ACCOUNT_NAME,
		t.ACCOUNT_NO,
		t.ACCOUNT_USE,
		GETDICNAME('ACCOUNT_USE',t.ACCOUNT_USE) ACCOUNT_USE_TEXT,
		t.ACCOUNT_DATE,
		t.REMARK,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE,
		GETDICNAME('IS_USE',t.IS_USE) IS_USE_TEXT,
		t.ACCOUNT_TYPE,
		GETDICNAME('ACCOUNT_TYPE',t.ACCOUNT_TYPE) ACCOUNT_TYPE_TEXT,
		nvl(a.abbr,a.org_name) as abbr,
		b.ACCOUNT_NAME as MODIFY_ACCOUNT_NAME,
		c.BANK_NAME,
		t.init_Money,
		(NVL(t.init_Money,0)+(select sum(nvl(a.debit_amount, 0)) - sum(nvl(a.lender_amount, 0))BALANCE
  from FM_BANK_JOURNAL a
 where a.is_use = 'Y'
   and a.bank_no = t.BANK_ACCOUNT_ID)) BALANCE
	 @}
from BAS_BANK_ACCOUNT t
left join bas_dic d on d.dic_code='ACCOUNT_PURPOSE' and t.ACCOUNT_PURPOSE = d.dic_value
left join bas_org a on t.org_id=a.org_id 
left join bas_emp_account b on t.MODIFY_ACCOUNT=b.account_id 
left join BAS_BANK c on t.bank_id=c.bank_id 
where t.BANK_ID in (WITH recursive temp AS (
	SELECT
		t.BANK_ID id 
	FROM
		BAS_BANK T 
	WHERE
		T.BANK_PID = #bankid# 
		OR T.BANK_ID = #bankid# UNION ALL
	SELECT
		t.BANK_ID id 
	FROM
		BAS_BANK T,
		temp 
	WHERE
		temp.id = T.BANK_PID 
	) SELECT
	DISTINCT * 
FROM
	temp) and t.is_use='Y'
@if(!isEmpty(orgid)){
and  a.org_id = #orgid#
@}
@if(!isEmpty(isEnAnble)){
 and nvl(t.IS_ENANBLE,'N') = #isEnAnble#
@}
@if(!isEmpty(search)){
and(
 upper(c.BANK_NAME) like #search#  or 
 upper(t.ACCOUNT_NAME) like #search#  or 
 upper(t.ACCOUNT_NO) like #search#  or 
 upper(t.ACCOUNT_USE) like #search#  or 
 upper(t.ACCOUNT_DATE) like #search#  or 
 upper(t.REMARK) like #search#  or 
 upper(t.MODIFY_ACCOUNT) like #search#  or 
 upper(t.MODIFY_TIME) like #search#  or 
 upper(d.dic_text) like #search#  or 
 upper(t.ACCOUNT_TYPE) like #search# or
 upper(a.org_name) like #search#
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.org_id,t.order_by 
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectBankAccountTree
===

WITH recursive temp AS (
	SELECT concat('b',	t.BANK_ID) id, t.BANK_ID,
		 concat('b', T.BANK_PID) PID, T.BANK_PID,
     	t.BANK_NAME text,
     	t.BANK_TYPE,
     	null as value
 FROM 	BAS_BANK T 
 WHERE 	t.IS_USE = 'Y'
 AND T.BANK_PID = 0 UNION ALL
	SELECT concat('b',	t.BANK_ID) id, t.BANK_ID,
		 concat('b', T.BANK_PID) PID, T.BANK_PID,
     	t.BANK_NAME text,
     	t.BANK_TYPE,
     	null as value
 FROM 	BAS_BANK T,temp WHERE temp.BANK_ID = T.BANK_PID
	) SELECT
	id,PID,text,BANK_TYPE,value
FROM
	temp 
 union all
SELECT concat('',t.bank_account_id) id, 
		concat('b',  T.BANK_ID) PID, 
     	concat(t.account_no,' ',t.account_name) text,
     	NULL AS BANK_TYPE,
        t.account_no as value
 FROM 	Bas_Bank_Account T 
 WHERE 	t.IS_USE = 'Y'

 
findDataByAccountData
===
SELECT T.*, T.ROWID
  FROM BAS_BANK_ACCOUNT T
 WHERE T.IS_USE = 'Y'
   and t.org_id =#orgId#
   and t.account_name =#bankName#
   and t.account_no =#bankAccount#
   
PageBasBankDeposit
===
select @pageTag(){
		t.BANK_ACCOUNT_ID,
		t.ORG_ID,
		t.BANK_ID,
		t.ACCOUNT_CLASS_ID,
		t.ACCOUNT_NAME,
		t.ACCOUNT_NO,
		t.ACCOUNT_USE,
		c.bank_name,
		t.ACCOUNT_DATE,
		nvl(e.THE_PERIOD_MONEY,0) THE_PERIOD_MONEY,
		nvl((SELECT nvl(i.init_money,0) FROM Fm_Balance_Init i 
                           WHERE i.IS_USE = 'Y' 
                           and i.balance_type = 2
                           and i.bank_account_id =t.bank_account_id ),0)+nvl((select sum(nvl(a1.debit_amount, 0))  -  sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time<=TRUNCATE(NOW(), 'MONTH')), 0) init_money,
nvl((select sum(nvl(a1.debit_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time>=TRUNCATE(NOW(), 'month') 
                                                                                  and a1.create_time<= NOW()), 0) month_sr,
nvl((select sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time>=TRUNCATE(NOW(), 'month')
                                                                                    and a1.create_time<= NOW()), 0) month_zc,
nvl((SELECT nvl(i.init_money,0) FROM Fm_Balance_Init i 
                           WHERE i.IS_USE = 'Y' 
                           and i.balance_type = 2
                           and i.bank_account_id =t.bank_account_id ),0)+nvl((select sum(nvl(a1.debit_amount, 0))  -  sum(nvl(a1.lender_amount, 0))
                                                                                  from FM_BANK_JOURNAL a1
                                                                                  where a1.is_use = 'Y' 
                                                                                  and a1.bank_no =t.bank_account_id
                                                                                  and a1.journal_type = 1
                                                                                  and a1.agree_status = 2
                                                                                  and a1.create_time<NOW()), 0) over_money,
		t.REMARK
	 @}
from BAS_BANK_ACCOUNT t
left join bas_org b on t.org_id=b.org_id 
left join BAS_BANK c on t.bank_id=c.bank_id 
left join (SELECT bj.*,(row_number() over(partition by bj.bank_no order by bj.BUSINESS_DATE,bj.BANK_JOURNAL_ID desc)) rn from FM_BANK_JOURNAL bj 
where bj.business_date<TRUNCATE(NOW(), 'mm') and bj.is_use='Y') d  on d.rn=1 and t.BANK_ACCOUNT_ID=d.bank_no 
left join (select * from (select NVL(a.the_period_money, 0) the_period_money,
                                      a.the_period_date,
                                      A.BANK_ACCOUNT_ID,
                                      row_number() over(partition by A.BANK_ACCOUNT_ID order by A.the_period_date desc, a.account_check_id desc) rn
                                 from FM_BANK_ACCOUNT_CHECK A
                                where A.IS_USE = 'Y'
                                  and a.check_status = 'Y') f
                        where rn = 1) e
              on t.bank_account_id = e.BANK_ACCOUNT_ID
where t.is_use='Y'
@if(!isEmpty(orgid)){
and  t.org_id = #orgid#
@}
@if(!isEmpty(search)){
and(
 upper(t.BANK_ACCOUNT_ID) like #search#  or 
 upper(t.ORG_ID) like #search#  or 
 upper(t.BANK_ID) like #search#  or 
 upper(t.ACCOUNT_CLASS_ID) like #search#  or 
 upper(t.ACCOUNT_NAME) like #search#  or 
 upper(t.ACCOUNT_NO) like #search#  or 
 upper(b.org_name) like #search#
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.org_id,t.ACCOUNT_DATE desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}
